import { Construct } from 'constructs/lib/construct';
import { RetentionDays } from 'aws-cdk-lib/aws-logs';
import { CfnRuleGroup, CfnWebACL } from 'aws-cdk-lib/aws-wafv2';
import { ExtendedConstruct } from '../../aws-cdk';
export type regionalBlockMode = 'count' | 'active';
export interface RegionalSecurityBaselineWebAclProps {
    /**
     * The mode of the rule group. To Block or to Count. By default it is set to count.
     */
    readonly mode?: regionalBlockMode;
    /**
     * The name of the webAcl.
     */
    readonly webAclName?: string;
    /**
     * The name of the rule group.
     */
    readonly name?: string;
    /**
     * The number of days log events are kept in CloudWatch Logs. Default is 1 year.
     */
    readonly logRetention?: RetentionDays;
    /**
     * The country codes to match against.
     */
    readonly countryCodes: string[];
    /**
     * The string to search for in the request.
     */
    readonly searchString: string;
    /**
     * This is the limit for country based rate based rule.
     */
    readonly uriCountryRuleLimit: number;
    /**
     * The action to take on the URI country rule.
     */
    readonly uriCountryAction?: 'count' | 'block';
    /**
     * The limit for the rate based rule.
     */
    readonly rateBasedRuleLimit: number;
}
/**
 * The `RegionalSecurityBaselineWebAcl` class represents a regional security baseline Web Access Control List (WebACL).
 * This WebACL is designed to provide a baseline level of security for your regional resources.
 * It includes rules for blocking or counting requests based on various conditions such as the country of origin and the request rate.
 */
export declare class RegionalSecurityBaselineWebAcl extends ExtendedConstruct {
    readonly regionalRuleGroup: CfnRuleGroup;
    readonly regionalWebAcl: CfnWebACL;
    constructor(scope: Construct, id: string, props?: RegionalSecurityBaselineWebAclProps);
}
